pub struct InMemorySeq { /* private fields */ }Expand description
In-memory sequence counter.
Resets on process restart — use only when the consumer either performs a fresh login
after restart (which establishes a new HDM session) or doesn’t care about cross-restart
continuity.
Implementations
Sourceimpl InMemorySeq
impl InMemorySeq
Sourcepub const fn starting_at(initial: i64) -> Self
pub const fn starting_at(initial: i64) -> Self
Start the counter so that the first call to Self::next returns initial + 1.
Sourcepub const fn from_zero() -> Self
pub const fn from_zero() -> Self
Start the counter so that the first call to Self::next returns 1.